/*
 * ServerException.cs
 *
 * Testing Framework
 * Version: 1.0
 *
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved
 *
 * Authors: real_vg, TCSDEVELOPER
 */

using System;

namespace TopCoder.Test.Framework.Servers
{
    /// <summary>
    /// The exception that is thrown by classes derived from the <see cref="Server"/> class
    /// when any error happens while processing.
    /// It is also thrown by the <see cref="ServerElement"/> class,
    /// when it fails to create a corresponding class derived from <see cref="Server"/>.
    /// </summary>
    ///
    /// <threadsafety static="true" instance="true"/>
    public class ServerException : ApplicationException
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ServerException"/> class
        /// with a specified error message.
        /// </summary>
        ///
        /// <param name="message">
        /// The message that describes the error.
        /// </param>
        public ServerException(string message)
            : base(message)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ServerException"/> class
        /// with a specified error message and a reference to the inner exception
        /// that is the cause of this exception.
        /// </summary>
        ///
        /// <param name="message">
        /// The message that describes the error.
        /// </param>
        /// <param name="innerException">
        /// The exception that is the cause of the current exception.
        /// </param>
        public ServerException(string message, Exception innerException)
            : base(message, innerException)
        {
        }
    }
}
