/*
 * TestApplicationServer.cs
 *
 * Testing Framework
 * Version: 1.0
 *
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved
 *
 * Author: TCSDEVELOPER
 */

using NAnt.Core.Types;
using NUnit.Framework;

namespace TopCoder.Test.Framework.Servers.Tests
{
    /// <summary>
    /// Unit tests for the <see cref="ApplicationServer"/> class.
    /// </summary>
    ///
    /// <remarks>
    /// Since <see cref="ApplicationServer"/> is an abstract class,
    /// it is tested via the empty <see cref="MyApplicationServer"/> class.
    /// </remarks>
    [TestFixture]
    public class TestApplicationServer
    {
        /// <summary>
        /// The ApplicationServer instance to test. Initialized in SetUp to MyApplicationServer instance.
        /// </summary>
        private ApplicationServer server;

        /// <summary>
        /// A sample Option collection. Initialized in SetUp.
        /// </summary>
        private OptionCollection options;

        /// <summary>
        /// Initializes the <see cref="ApplicationServer"/> instance to test
        /// via <see cref="MyApplicationServer"/> and prepares a sample option collection.
        /// </summary>
        [SetUp]
        public void SetUp()
        {
            server = new MyApplicationServer();

            // prepare a sample option collection
            options = new OptionCollection();

            // deployment_dir
            Option optDeploy = new Option();
            optDeploy.OptionName = ApplicationServer.DEPLOYMENT_DIR;
            optDeploy.Value = @"somewhere\somepath";
            options.Add(optDeploy);
        }

        /// <summary>
        /// Tests static constants definitions.
        /// </summary>
        [Test]
        public void TestStatic()
        {
            Assert.AreEqual("deployment_dir", ApplicationServer.DEPLOYMENT_DIR, "DEPLOYMENT_DIR value is incorrect");
        }

        /// <summary>
        /// Tests DeploymentDirectory property. Make sure it retrieves OptionCollection correctly.
        /// </summary>
        [Test]
        public void TestDeploymentDirectory()
        {
            // set the options first and assert
            server.Options = options;
            Assert.AreEqual(@"somewhere\somepath", server.DeploymentDirectory,
                "DeploymentDirectory value as in the options");
        }

        /// <summary>
        /// Tests DeploymentDirectory property given ApplicationServer with null option collection.
        /// Expecting ServerException.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ServerException))]
        public void TestDeploymentDirectoryNullCollection()
        {
            string val = server.DeploymentDirectory;
        }

        /// <summary>
        /// Tests DeploymentDirectory property given option collection that contains no deployment_dir key.
        /// Expecting ServerException.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ServerException))]
        public void TestDeploymentDirectoryNotExists()
        {
            // remove deployment_dir from options
            options.Remove(options[ApplicationServer.DEPLOYMENT_DIR]);
            server.Options = options;
            string val = server.DeploymentDirectory;
        }
    }
}
